from setuptools import setup, find_packages

setup(
    name='file_scan_dd',
    version='0.1',
    py_modules=['file_scan_dd'],
    install_requires=[],
    description='A simple library to scan files using metadefender',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)